import { CrysteamPortal, RoutePermission } from "@crysteam/portal";
export type UserProfile = {
    id: string;
    username: string;
    locale: string;
    role: string;
    discordId: string;
    minecraftUuid?: string;
    telegramId?: string;
    referralId?: string;
    avatarUri: string;
    lastLoginAt: Date;
    recentIp: string;
};
export type UserRegistrationData = Omit<UserProfile, "id" | "role" | "lastLoginAt" | "recentIp">;
export type PassportOptions = {
    portal: CrysteamPortal;
    scopes?: RoutePermission[];
    host?: string;
};
export type Tokens = {
    accessToken: string;
    refreshToken: string;
};
export declare class PassportClient {
    private readonly _portal;
    private readonly _host;
    private readonly _customScopes?;
    private readonly _userCache;
    private _http?;
    private _availableScopes?;
    constructor(options: PassportOptions);
    private _initialize;
    private _hasScope;
    authorization(data: {
        code: string;
        redirectUri: string;
        referralId?: string;
    }): Promise<Tokens>;
    refreshToken(refresh_token: string): Promise<Tokens>;
    verify(access_token: string): Promise<UserProfile>;
    registerUser(data: UserRegistrationData): Promise<UserProfile>;
    updateUser(id: string, update: Partial<UserProfile>): Promise<UserProfile>;
    deleteUserByQuery(query: string): Promise<UserProfile>;
    fetchUsers(where: object, limit?: number): Promise<UserProfile[]>;
    fetchUserByQuery(query: string, useCache?: boolean): Promise<UserProfile>;
    getUserById(id: string, useCache?: boolean): Promise<UserProfile>;
}
